@@ -1,4 +1,4 @@
-from typing import Callable, List, Optional, TypeVar, Union, cast
+from typing import Callable, List, Optional, TypeVar, Union, cast, Type
 
 from pyspark.sql import Column, DataFrame
 
@@ -24,6 +24,11 @@ _TAutoMapperDataType = TypeVar(
     "_TAutoMapperDataType", bound=Union["AutoMapperDataTypeBase"]
 )
 
+# used for casting
+_TAutoMapperDataType2 = TypeVar(
+    "_TAutoMapperDataType2", bound=Union["AutoMapperDataTypeBase"]
+)
+
 
 class AutoMapperDataTypeBase:
     # noinspection PyMethodMayBeStatic
@@ -436,3 +441,49 @@ class AutoMapperDataTypeBase:
                 column=self, pattern=pattern, replacement=replacement
             ),
         )
+
+    # noinspection PyMethodMayBeStatic
+    def if_exists(
+        self: _TAutoMapperDataType,
+        if_exists: Optional[_TAutoMapperDataType] = None,
+        if_not_exists: Optional[_TAutoMapperDataType] = None,
+    ) -> _TAutoMapperDataType:
+        """
+        returns column if it exists else returns null
+
+
+        :return: an automapper type
+        """
+        from spark_auto_mapper.data_types.if_column_exists import (
+            AutoMapperIfColumnExistsType,
+        )
+
+        if not if_exists:
+            if_exists = self
+
+        # cast it to the inner type so type checking is happy
+        return cast(
+            _TAutoMapperDataType,
+            AutoMapperIfColumnExistsType(
+                column=self, if_exists=self, if_not_exists=if_not_exists
+            ),
+        )
+
+    # noinspection PyMethodMayBeStatic,PyUnusedLocal
+    def cast(
+        self: _TAutoMapperDataType, type_: Type[_TAutoMapperDataType2]
+    ) -> _TAutoMapperDataType2:
+        """
+        casts columns to type
+
+
+        :return: an automapper type
+        """
+
+        # cast it to the inner type so type checking is happy
+        return cast(_TAutoMapperDataType2, self)
+
+    def __add__(
+        self: _TAutoMapperDataType, other: _TAutoMapperDataType
+    ) -> _TAutoMapperDataType:
+        return self.concat(other)
